# DeviceLed

Describes the State of a led for API.

## Properties
Name | Type | Description | Notes
------------ | ------------- | ------------- | -------------
**led_index** | **int** |  | 
**label** | **str** |  | [optional] 
**state_index** | **int** |  | [optional] 
**state_count** | **int** |  | [optional] 
**led_id** | **str** |  | 
**state_label** | **str** |  | [optional] 

[[Back to Model list]](../README.md#documentation-for-models) [[Back to API list]](../README.md#documentation-for-api-endpoints) [[Back to README]](../README.md)


